@@ -41,13 +41,25 @@ module AssetSync
       expand_file_names(self.config.ignored_files)
     end
 
+    def get_manifest_path
+      return [] unless self.config.include_manifest
+
+      if ActionView::Base.respond_to?(:assets_manifest)
+        manifest = Sprockets::Manifest.new(ActionView::Base.assets_manifest.environment, ActionView::Base.assets_manifest.dir)
+        manifest_path = manifest.filename
+      else
+        manifest_path = self.config.manifest_path
+      end
+      [manifest_path.sub(/^#{path}\//, "")] # full path to relative path
+    end
+
     def local_files
       @local_files ||=
         (get_local_files + config.additional_local_file_paths).uniq
     end
 
     def always_upload_files
-      expand_file_names(self.config.always_upload)
+      expand_file_names(self.config.always_upload) + get_manifest_path
     end
 
     def files_with_custom_headers
@@ -58,7 +70,10 @@ module AssetSync
       self.config.invalidate.map { |filename| File.join("/", self.config.assets_prefix, filename) }
     end
 
-    def get_local_files
+    # @api
+    #   To get a list of asset files indicated in a manifest file.
+    #   It makes sense if a user sets `config.manifest` is true.
+    def get_asset_files_from_manifest
       if self.config.manifest
         if ActionView::Base.respond_to?(:assets_manifest)
           log "Using: Rails 4.0 manifest access"
@@ -80,6 +95,13 @@ module AssetSync
           log "Warning: Manifest could not be found"
         end
       end
+    end
+
+    def get_local_files
+      if from_manifest = get_asset_files_from_manifest
+        return from_manifest
+      end
+
       log "Using: Directory Search of #{path}/#{self.config.assets_prefix}"
       Dir.chdir(path) do
         to_load = self.config.assets_prefix.present? ? "#{self.config.assets_prefix}/**/**" : '**/**'
@@ -110,9 +132,15 @@ module AssetSync
       from_remote_files_to_delete = remote_files - local_files - ignored_files - always_upload_files
 
       log "Flagging #{from_remote_files_to_delete.size} file(s) for deletion"
-      # Delete unneeded remote files
-      bucket.files.each do |f|
-        delete_file(f, from_remote_files_to_delete)
+      # Delete unneeded remote files, if we are on aws delete in bulk else use sequential delete
+      if self.config.aws? && connection.respond_to?(:delete_multiple_objects)
+        from_remote_files_to_delete.each_slice(500) do |slice|
+          connection.delete_multiple_objects(config.fog_directory, slice)
+        end
+      else
+        bucket.files.each do |f|
+          delete_file(f, from_remote_files_to_delete)
+        end
       end
     end
 
@@ -126,10 +154,17 @@ module AssetSync
       file = {
         :key => f,
         :body => file_handle,
-        :public => true,
         :content_type => mime
       }
 
+      # region fog_public
+
+      if config.fog_public.use_explicit_value?
+        file[:public] = config.fog_public.to_bool
+      end
+
+      # endregion fog_public
+
       uncompressed_filename = f.sub(/\.gz\z/, '')
       basename = File.basename(uncompressed_filename, File.extname(uncompressed_filename))
 
@@ -214,10 +249,20 @@ module AssetSync
       local_files_to_upload = local_files - ignored_files - remote_files + always_upload_files
       local_files_to_upload = (local_files_to_upload + get_non_fingerprinted(local_files_to_upload)).uniq
 
-      # Upload new files
-      local_files_to_upload.each do |f|
-        next unless File.file? "#{path}/#{f}" # Only files.
-        upload_file f
+      if self.config.concurrent_uploads
+        threads = ThreadGroup.new
+        # Upload new files
+        local_files_to_upload.each do |f|
+          next unless File.file? "#{path}/#{f}" # Only files.
+          threads.add(Thread.new { upload_file f })
+        end
+        sleep 1 while threads.list.any? # wait for threads to finish uploading
+      else
+        # Upload new files
+        local_files_to_upload.each do |f|
+          next unless File.file? "#{path}/#{f}" # Only files.
+          upload_file f
+        end
       end
 
       if self.config.cdn_distribution_id && files_to_invalidate.any?
